@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 from __future__ import absolute_import
-from flaskext.script import Manager
-from flaskext.celery import install_commands as install_celery_commands
+from flask.ext.script2 import Manager
+from flask.ext.celery import install_commands as install_celery_commands
 
 from myapp import create_app
 
